"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const devices_1 = __importDefault(require("../devices"));
const viewportStringPattern = /^(\d{1,4})(?:x)?(\d{1,4})?$/;
const partialViewport = {
    deviceScaleFactor: 1,
    hasTouch: false,
    isMobile: false,
    isLandscape: false,
};
function getViewport(input) {
    if (lodash_1.default.isNumber(input)) {
        return Object.assign({}, partialViewport, { width: input, height: input });
    }
    if (lodash_1.default.isString(input)) {
        // Test if the string match "0000x0000" or "0000" and construct
        // the viewport object using the result of the match
        if (viewportStringPattern.test(input)) {
            const [, width, height] = viewportStringPattern.exec(input);
            return Object.assign({}, partialViewport, { width: parseInt(width, 10), height: parseInt(height || width, 10) });
        }
        else {
            input = input.replace(/\s+/g, "-").toLowerCase();
            return lodash_1.default.find(devices_1.default, {
                name: input,
            });
        }
    }
    if (lodash_1.default.isObject(input)) {
        return lodash_1.default.merge({}, partialViewport, input);
    }
}
exports.getViewport = getViewport;
function getViewports(input) {
    return input.map((v) => getViewport(v));
}
exports.getViewports = getViewports;
