"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_html_1 = __importDefault(require("is-html"));
const is_valid_path_1 = __importDefault(require("is-valid-path"));
exports.isValidPath = is_valid_path_1.default;
const lodash_1 = __importDefault(require("lodash"));
// Output type validation
const notBase64 = /[^A-Z0-9+/=]/i;
const supportedTypes = ["pdf", "png", "jpeg", "html", "base64", "buffer"];
// Viewport validation
const viewportObject = lodash_1.default.conforms({
    height: lodash_1.default.isNumber,
    width: lodash_1.default.isNumber,
});
function isValidViewportObject(v) {
    return viewportObject(v);
}
exports.isValidViewportObject = isValidViewportObject;
function validateType(v) {
    v = v.toLowerCase();
    if (supportedTypes.includes(v)) {
        return v;
    }
    throw new Error(`The output type ${v} is not supported, must be one of [${supportedTypes.join(",")}]`);
}
exports.validateType = validateType;
function isValidBase64(v) {
    const len = v.length;
    if (!len || len % 4 !== 0 || notBase64.test(v)) {
        return false;
    }
    const firstPaddingChar = v.indexOf("=");
    return firstPaddingChar === -1 ||
        firstPaddingChar === len - 1 ||
        (firstPaddingChar === len - 2 && v[len - 1] === "=");
}
exports.isValidBase64 = isValidBase64;
function isValidURL(v) {
    return /^(https?|file):\/\/|^data:/.test(v);
}
exports.isValidURL = isValidURL;
function isValidHTML(v) {
    return is_html_1.default(v);
}
exports.isValidHTML = isValidHTML;
